/**
 * Abstraction for localStorage that uses an in-memory fallback when localStorage throws an error.
 * Reasons for throwing an error:
 * - maximum quota is exceeded
 * - under Mobile Safari (since iOS 5) when the user enters private mode `localStorage.setItem()`
 *   will throw
 * - trying to access localStorage object when cookies are disabled in Safari throws
 *   "SecurityError: The operation is insecure."
 */
declare const _default: {
    data: Map<string, unknown>;
    get<T>(key: string, defaultValue: T): T | undefined;
    set<T_1>(key: string, value: T_1): void;
    remove(key: string): void;
};
export default _default;
